#
# spec file for package cosmic-launcher
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname com.system76.CosmicLauncher
Name:           cosmic-launcher
Version:        1.0.0~alpha7+0
Release:        1.1
Summary:        Layer Shell frontend
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-launcher
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  just
BuildRequires:  mold
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xkbcommon)

%description
Layer Shell frontend for pop-launcher. Currently
the underlying protocol being used in the plugin for managing toplevels
in wayland is defined here but it will be switched to use wlr-foreign-toplevel-management
when it is ready.

%prep
%autosetup -a1

%build
just build-release

%install
just rootdir=%{buildroot} prefix=%{_prefix} install

%check
%{cargo_test}

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{appname}.svg
%{_datadir}/metainfo/%{appname}.metainfo.xml

%changelog
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 1.0.0~alpha7+0:
  * i18n(ar): improve and complete translations (#285)
  * i18n - update portuguese translations (#281)
  * i18n(ro): Add Romanian translation (#280)
  * Add es-419 translations (#157)
  * Added German Translation (#166)
  * Polish translation for desktop entry (#247)
  * Added Irish translation (#252)
  * Update metainfo with the Hungarian translation (#253)
  * Create cosmic_launcher.ftl (#266)
  * i18n(sk): Add Slovak translations (#275)
  * Minor fix (#278)
  * i18n (pt-BR) Update translations
  * chore: update libcosmic
  * chore: update libcosmic
  * fix: add 16 px margin
  * fix: filter out overlaps past half of surface height
  * chore: udpate libcosmic
  * i18n/es fix
  * fix: ignore exclusive_zone
  * feat: avoid overlap
  * fix(libcosmic): theme subscription
  * i18n(ca): Add Catalan translation
  * fix license references
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+0:
  * chore: upgrade dependencies
  * i18n(zh): Update translation of zh-CN and zh-TW
  * Update Hungarian translations
  * feat: set max responses for the launcher service
  * fix: ids
  * refactor: add scrollable list after 8 items
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+0:
  * i18n(hu): add Hungarian translation
  * i18n: ensure COSMIC is capitalized
  * i18n(pt-BR): translation update
  * i18n(pt): add type-to-search translation
  * i18n: add Javanese translation
  * i18n: add Hindi & Kannada translation
  * i18n: add nl, jp, es, fr, it translations
  * i18n(zh-cn): add translation
  * i18n(tr): add translation
  * i18n(pl): add translation
  * i18n(ar): add translation
  * perf: optimized cosmic-freedesktop-icons
  * chore: replace freedesktop-icons with cosmic-freedesktop-icons
  * perf: update freedesktop-icons to reduce memory usage
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+1:
  * update deps
  * chore: update libcosmic
  * update libcosmic
  * cleanup
  * update libcosmic
  * fix justfile
  * fix compile
  * use github fork instead of path
  * impl queue + some refractor
  * use debug log level when debug mode
  * journald support
  * remove comment
  * re add if self.last_hide.elapsed().as_millis() > 100
  * add debug variable to justfile
  * do not close the service every time
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * update pop-launcher
  * improv: increase truncate limit
  * update libcosmic
  * Correct the filename for the Swedish translation (#189)
  * i18n(sv): add translation
  * chore: padding fixes
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * improv: increase truncate limit
  * update dependencies
- require rust >= 1.80
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * fix: zombie processes
  * chore: padding fixes
  * Updated translations
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * fix: tab complete index calculation and cursor
  * fix: do nothing for focus next/prev if list is empty
  * fix: set width of list contents using FillPortion
  * chore(desktop-file): remove ICED as a category
- enable leap (thanks to vyvir)
* Wed Mar 13 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
